@@ -1,4 +1,4 @@
-# Author: Oscar Perpinan Lamigueiro oscar.perpinan@upm.es
+# Author: Oscar Perpinan Lamigueiro oscar.perpinan@gmail.es
 # Date :  June 2011
 # Version 0.10
 # Licence GPL v3
@@ -83,6 +83,16 @@ RdBuTheme <- function(region=brewer.pal(9, 'RdBu'), ...) {
   theme
 }
 
+BuRdTheme <- function(region=rev(brewer.pal(9, 'RdBu')), ...) {
+  theme <- rasterTheme(region=region, ...)
+  theme
+}
+
+PuOrTheme <- function(region=brewer.pal(9, 'PuOr'), ...) {
+  theme <- rasterTheme(region=region, ...)
+  theme
+}
+
 GrTheme <- function(region=rev(brewer.pal(9, 'Greys')), ...) {
   theme <- rasterTheme(region=region, ...)
   theme
@@ -93,9 +103,17 @@ BTCTheme <- function(region=BTC(n=9), ...) {
   theme
 }
 
+streamTheme <- function(region='black',
+                        symbol=brewer.pal(n=5, name='Blues'),
+                        alpha=0.6, 
+                        panel.background=list(col='gray20'),
+                        ...){
+  theme <- rasterTheme(region=region, symbol=symbol, ...)
+  theme <- modifyList(theme, list(panel.background=panel.background))
+  theme
+}
 
 ##Auxiliary function for densityplot, histogram and bwplot
-
 raster2dat <- function(x, FUN, maxpixels){
   nl <- nlayers(x)
   if (maxpixels < ncell(x)) {
